@@ -455,15 +455,6 @@ class Connection():
             for item in result:
                 for _include in self._include:
                     item[_include].__reset__()
-                    print()
-                    print()
-                    print()
-                    print()
-                    print(item[_include].__class__)
-                    print()
-                    print()
-                    print()
-                    print()
                     item.__metadata__['relasionships'][_include] = None if not 'List' in item[_include].__class__.__name__ else []
                     _stetament_include = self.__format_include_query__(item, _include)
                     if _stetament_include:
@@ -563,6 +554,15 @@ class Connection():
         self._conn.save(query, {})
         self._conn.commit()
 
+    def update(self, **kwargs):
+        _where = [w for w in self._where if self.__is__main_codition__(w)] if self._where else []
+        _where = f" WHERE ({' AND '.join(_where)})" if len(_where) > 0 else ''
+        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is__main_codition__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
+        update = ",".join([f"{k}='{v}'" for k,v in kwargs.items()])
+        query = f"UPDATE {self._table} SET {update} {_where}{_orwhere}"
+        self._conn.save(query, {})
+        self._conn.commit()
+
     def save(self):
 
         # DELETE OBJECTS
