@@ -155,7 +155,7 @@ def Make(dir, db_user, db_password, db_host, db_port, db_database, db_ssl=False,
                     colum_config.append("auto_increment=True")
                 if table_column["IS_NULLABLE"] == "NO":
                     colum_config.append("not_null=True")
-                if table_column["CHARACTER_MAXIMUM_LENGTH"] != "NULL" and table_column["CHARACTER_MAXIMUM_LENGTH"] != None AND decorator != 'Json':
+                if table_column["CHARACTER_MAXIMUM_LENGTH"] != "NULL" and table_column["CHARACTER_MAXIMUM_LENGTH"] != None and decorator != 'Json':
                     colum_config.append(
                         "max=%s" % table_column["CHARACTER_MAXIMUM_LENGTH"])
                 if table_column["NUMERIC_PRECISION"] != None:
